==> haskell-shellmet-0.0.5.0-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-shellmet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 shellmet
version:              0.0.5.0
visibility:           public
id:                   shellmet-0.0.5.0-507Bvxuj8pb1Uv2gsBAmHQ
key:                  shellmet-0.0.5.0-507Bvxuj8pb1Uv2gsBAmHQ
license:              MPL-2.0
copyright:            2019-2022 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Dmitrii Kovanikov
homepage:             https://github.com/kowainik/shellmet
synopsis:             Out of the shell solution for scripting in Haskell
description:
    Shellmet provides easy and convenient way to call shell commands from Haskell programs

category:             Shell, Command Line
abi:                  876da29310bea7ae0c7117052a954081
exposed:              True
exposed-modules:      Shellmet
import-dirs:          /usr/lib/ghc-9.4.8/site-local/shellmet-0.0.5.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/shellmet-0.0.5.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/shellmet-0.0.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-shellmet
hs-libraries:         HSshellmet-0.0.5.0-507Bvxuj8pb1Uv2gsBAmHQ
depends:              base-4.17.2.1 process-1.6.18.0 text-2.0.2
haddock-interfaces:   /usr/share/doc/haskell-shellmet/html/shellmet.haddock
haddock-html:         /usr/share/doc/haskell-shellmet/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-shellmet-0.0.5.0-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-shellmet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 shellmet
version:              0.0.5.0
visibility:           public
id:                   shellmet-0.0.5.0-JIXkLY5yAio6IbNeC9UwDG
key:                  shellmet-0.0.5.0-JIXkLY5yAio6IbNeC9UwDG
license:              MPL-2.0
copyright:            2019-2022 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Dmitrii Kovanikov
homepage:             https://github.com/kowainik/shellmet
synopsis:             Out of the shell solution for scripting in Haskell
description:
    Shellmet provides easy and convenient way to call shell commands from Haskell programs

category:             Shell, Command Line
abi:                  0b7e9306c635738aa5da0cd61ac29ab8
exposed:              True
exposed-modules:      Shellmet
import-dirs:          /usr/lib/ghc-9.4.8/site-local/shellmet-0.0.5.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/shellmet-0.0.5.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/shellmet-0.0.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-shellmet
hs-libraries:         HSshellmet-0.0.5.0-JIXkLY5yAio6IbNeC9UwDG
depends:              base-4.17.2.1 process-1.6.18.0 text-2.0.2
haddock-interfaces:   /usr/share/doc/haskell-shellmet/html/shellmet.haddock
haddock-html:         /usr/share/doc/haskell-shellmet/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
